### Name: distsamp
### Title: Fit the hierarchical distance sampling model of Royle et al.
###   (2004)
### Aliases: distsamp
### Keywords: models

### ** Examples
## Line transect examples

data(linetran)

ltUMF <- with(linetran, {
        unmarkedFrameDS(y = cbind(dc1, dc2, dc3, dc4), 
        siteCovs = data.frame(Length, area, habitat), 
        dist.breaks = c(0, 5, 10, 15, 20),
        tlength = linetran$Length * 1000, survey = "line", unitsIn = "m")
        })

ltUMF
summary(ltUMF)
hist(ltUMF)

# Half-normal detection function. Density output (log scale). No covariates. 
(fm1 <- distsamp(~ 1 ~ 1, ltUMF))

# Some methods to use on fitted model
summary(fm1)
coef(fm1, type="det", altNames=TRUE)
backTransform(fm1, whichEstimate="det")
vcov(fm1, altNames=TRUE)
confint(fm1, type = "state")
predict(fm1, type = "state")
hist(fm1)       # This only works when there are no detection covariates

# Half-normal. Abundance output. No covariates. Note that transect length
# must be accounted for so abundance is animals per km of transect.
summary(fm2 <- distsamp(~ 1 ~ 1, ltUMF, output="abund", unitsOut="kmsq"))

# Halfnormal. Covariates affecting both density and and detection.  
(fm3 <- distsamp(~ poly(area, 2) + habitat ~ habitat, ltUMF))

# Negative exponential detection function.
(fm4 <- distsamp(~ 1 ~ 1, ltUMF, key="exp"))
hist(fm4, col="blue", ylim=c(0, 0.1), xlab="Distance (m)")

# Hazard-rate detection function. Density output in hectares.
summary(fmhz <- distsamp(~ 1 ~ 1, ltUMF, keyfun="hazard"))
hist(fmhz)

# Plot detection function.
fmhz.shape <- exp(coef(fmhz, type="det"))
fmhz.scale <- exp(coef(fmhz, type="scale"))
plot(function(x) gxhaz(x, shape=fmhz.shape, scale=fmhz.scale), 0, 25, 
        xlab="Distance (m)", ylab="Detection probability")

# Uniform detection function. Density output in hectars.
(fmu <- distsamp(~ 1 ~ 1, ltUMF, key="uniform"))

## Point transect example

data(pointtran)

ptUMF <- with(pointtran, {
        unmarkedFrameDS(y = cbind(dc1, dc2, dc3, dc4, dc5), 
        siteCovs = data.frame(area, habitat), 
        dist.breaks = seq(0, 25, by=5), survey = "point", unitsIn = "m")
        })

# Half-normal. Output is animals / ha on log-scale. No covariates.
summary(fmp1 <- distsamp(~ 1 ~ 1, ptUMF))
hist(fmp1, ylim=c(0, 0.07))




